Possible improvements
=====================

* improve docstrings
* typing annotations
* improve mosaicking algorithm
* improve documentation theme and styling
* corrections (and coordinates) interpolation (bi-linear)
* replace returned dictionaries (with 'x', 'y', 'units', etc. keys)
  with named tuples (TBD)
